# DetVisLib
Detections Visualization Library - easy to use library to visualize detections from various object detection frameworks.

## Installation
```pip install detvislib```

## How to use it?
Create DetVisLib object and use its methods. More detailed description will be added soon

## License

© 2021 Jan Gąsienica-Józkowy

This repository is licensed under the MIT license. See LICENSE for details.
